==> dl.php?src=linea21_2_3_0.zip: linea21/languages/fr/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "plan d'actions";

/*	nommage des modules
 *  	*/
$lang['project']['name']="projet";
$lang['project']['confirm_add'] = "Ajout du projet réalisé avec succès\n";
$lang['project']['confirm_mod'] = "Modification du projet réalisée avec succès\n";
$lang['project']['confirm_sup'] ="Suppression du projet réalisée avec succès\n";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Ajout d'un ".$lang['project']['name'];
$lang['project']['mod']= "Modification du ".$lang['project']['name'];
$lang['project']['sup']= "Suppression du ".$lang['project']['name'];
$lang['project']['det']= "Détails du ".$lang['project']['name'];
$lang['project']['list']= "Consultation des projets";



/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Saisie des informations du nouveau ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nom du ".$lang['project']['name'];
$lang['project']['goal']="objectif(s)";
$lang['project']['opgoal']="objectif opérationnel";
$lang['project']['description']="description";
$lang['project']['body']="contenu";
$lang['project']['budget']="budget (en €)";
$lang['project']['budget_comment']="budget - complément";
$lang['project']['elected']="élu(s) référent(s)";
$lang['project']['manager']="responsable(s)";
$lang['project']['coordinator']="coordinateur(s)";
$lang['project']['team']="équipe projet";
$lang['project']['partners']="partenaires";
$lang['project']['begin_date']="début du projet";
$lang['project']['estimated_date']="fin estimée";
$lang['project']['end_date']="fin effective";
$lang['project']['progression']="réalisation (en %)";
$lang['project']['parent']="projet parent";
$lang['project']['sub-projects']="sous projets";
$lang['project']['priority']="priorité";
$lang['project']['level']="niveau";
$lang['project']['workshop']="groupe de travail";
$lang['project']['comment']="commentaire";
$lang['project']['sdi']="indicateurs ";
$lang['project']['scale']="échelle";
$lang['project']['author']="auteur";
$lang['project']['statut']='état de publication';
$lang['project']['add_indicator']="ajouter un indicateur";
$lang['project']['add_indicator_value']="ajouter une valeur";
$lang['project']['completion']="complétion";
$lang['project']['report']="Export / création d'un rapport";

$lang['project']['steering_title']='Pilotage / animation';
$lang['project']['calendar_title']='Programmation';
$lang['project']['budget_title']='Budget et moyens';
$lang['project']['finalities']='Finalités';

// views
$lang['project']['level_view']='Vue par niveaux';
$lang['project']['flat_view']='Affichage plat';
$lang['project']['finality_view']='Vue par finalités';


/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" derniers ajouts effectués";
$lang['project']['qb_titlemod']=" dernières modifications effectuées";
$lang['project']['qb_titlesup']=" dernières suppressions effectuées";
$lang['project']['qb_titlepubli']=' dernières publications effectuées';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Faites votre choix dans la liste ci dessous --";

$lang['project']['nb_total']='projets sont stockés dans la base de données.';
$lang['project']['statut_filter']='Afficher par statut';
$lang['project']['all']='Afficher la liste complete';
$lang['project']['noresult']='Aucun projet ne correspond à ce critère de sélection ';
$lang['project']['session-stored']="une sélection de %s projets est en mémoire";

/*	messages
 *  	*/
$lang['project']['no_name']="Vous devez impérativement entrer un nom à votre projet";
$lang['project']['no_description']="Votre projet doit impérativement avoir une description";
$lang['project']['no_body']="Votre projet doit impérativement avoir un contenu";
$lang['project']['no_scale']='Votre projet doit impérativement être associé à une échelle';
$lang['project']['no_level']='Votre projet doit impérativement être associé à un niveau';
$lang['project']['no_priority']='Votre projet doit impérativement être associé à une priorité';
$lang['project']['progression_error']='L\'indicateur de réalisation doit prendre une valeur entre 0 et 100.';
$lang['project']['incorrect_user']='Le responsable renseigné \'%s\' est inconnu de l\'application';
$lang['project']['incorrect_userperm']='Le responsable \'%s\' n\'a pas les permissions suffisantes';
$lang['project']['budget_integer']='Budget : un chiffre entier doit être entré';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';
$lang['project']['inconsistent_date']='Les dates saisies ne semblent pas cohérentes. Veuillez les vérifier.';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Pour ajouter un projet, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['project']['help_add2']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_add3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['project']['help_list1']="Pour afficher un projet en détail, cliquez sur le nom de celui-ci";
$lang['project']['help_list2']="Vous pouvez supprimer un projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_list3']="Vous pouvez modifier un projet en cliquant sur l'icône de modification qui lui est associée";
$lang['project']['help_list4']="Pour ajouter un projet, cliquez sur le lien 'ajouter un projet' dans la barre de titre";
$lang['project']['help_list5']="Vous pouvez faire une recherche de projet à tout moment en cliquant sur 'recherche'";

$lang['project']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['project']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['project']['help_det1']="Pour afficher le projet parent du projet détaillé, cliquez sur le nom de celui-ci";
$lang['project']['help_det2']="Vous pouvez supprimer ce projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_det3']="Vous pouvez modifier ce projet en cliquant sur l'icône de modification qui lui est associée";

$lang['project']['help_sup1']="Attention, si ce projet contient des sous projets ils ne seront pas automatiquement effacés";
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/fr/lang_project.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



$lang['project']['section'] = "plan d'actions";

/*	nommage des modules
 *  	*/
$lang['project']['name']="projet";
$lang['project']['confirm_add'] = "Ajout du projet réalisé avec succès\n";
$lang['project']['confirm_mod'] = "Modification du projet réalisée avec succès\n";
$lang['project']['confirm_sup'] ="Suppression du projet réalisée avec succès\n";
$lang['project']['mine']="Mes projets";
$lang['project']['all']="Ensemble des projets";


/*	nommage rubrique module
 *  	*/
$lang['project']['add']= "Ajout d'un ".$lang['project']['name'];
$lang['project']['mod']= "Modification du ".$lang['project']['name'];
$lang['project']['sup']= "Suppression du ".$lang['project']['name'];
$lang['project']['det']= "Détails du ".$lang['project']['name'];
$lang['project']['list']= "Consultation des projets";

$lang['project']['modify_actors']='Modifier les acteurs';
$lang['project']['modify_actors_notice']='Pour mettre à jour un acteur, cliquez directement sur le texte et faites vos modifications.';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['project']['add_title']="Saisie des informations du nouveau ".$lang['project']['name'];

/*	nommage élément rubrique
 *  	*/
$lang['project']['name']="nom du ".$lang['project']['name'];
$lang['project']['target']="cible(s)";
$lang['project']['goal']="objectif(s)";
$lang['project']['opgoal']="objectif opérationnel";
$lang['project']['description']="description";
$lang['project']['body']="contenu";
$lang['project']['budget']="budget (en €)";
$lang['project']['budget_comment']="budget - complément";
$lang['project']['elected']="élu(s) référent(s)";
$lang['project']['manager']="responsable(s)";
$lang['project']['coordinator']="coordinateur(s)";
$lang['project']['team']="équipe projet";
$lang['project']['partners']="partenaires";
$lang['project']['begin_date']="début du projet";
$lang['project']['estimated_date']="fin estimée";
$lang['project']['end_date']="fin effective";
$lang['project']['cal_comment']="calendrier - complément";
$lang['project']['progression']="réalisation (en %)";
$lang['project']['progression_sync']="synchroniser sur les tâches";
$lang['project']['parent']="projet parent";
$lang['project']['sub-projects']="sous projets";
$lang['project']['priority']="priorité";
$lang['project']['level']="niveau";
$lang['project']['workshop']="groupe de travail";
$lang['project']['impacts']="impacts";
$lang['project']['comment']="commentaire";
$lang['project']['sdi']="indicateurs ";
$lang['project']['sdi_s']="indicateur";
$lang['project']['scale']="échelle";
$lang['project']['author']="auteur";
$lang['project']['statut']='état de publication';
$lang['project']['add_indicator']="ajouter un indicateur";
$lang['project']['add_indicator_value']="ajouter une valeur";
$lang['project']['completion']="complétion";
$lang['project']['report']="Export / création d'un rapport";

$lang['project']['steering_title']='Pilotage / animation';
$lang['project']['calendar_title']='Programmation';
$lang['project']['tasks_title']='Tâches programmées';
$lang['project']['budget_title']='Budget et moyens';
$lang['project']['finalities']='Finalités';

$lang['project']['impacts'] = "Impacts";
$lang['project']['impactsItems']['Energy']="Energie";
$lang['project']['impactsItems']['GHG']="GES";
$lang['project']['impactsItems']['Air']="Qualité de l'air";

// views
$lang['project']['level_view']='Vue par niveaux';
$lang['project']['flat_view']='Affichage plat';
$lang['project']['finality_view']='Vue par finalités';

/*	nommage quickbox
 *  	*/
$lang['project']['qb_titleadd']=" derniers ajouts effectués";
$lang['project']['qb_titlemod']=" dernières modifications effectuées";
$lang['project']['qb_titlesup']=" dernières suppressions effectuées";
$lang['project']['qb_titlepubli']=' dernières publications effectuées';

/*	divers
 *  	*/
$lang['project']['select_choice']="-- Faites votre choix dans la liste ci dessous --";

$lang['project']['nb_total']='projets sont stockés dans la base de données.';
$lang['project']['statut_filter']='Afficher par statut';
$lang['project']['all']='Afficher la liste complète';
$lang['project']['completion-percentage']='%s %% des actions ont été réalisées';
$lang['project']['report']="Export / création d'un rapport";
$lang['project']['noresult']='Aucun projet ne correspond à ce critère de sélection ';
$lang['project']['session-stored']="une sélection de %s projets est en mémoire";

/*	messages
 *  	*/
$lang['project']['no_name']="Vous devez impérativement entrer un nom à votre projet";
$lang['project']['no_description']="Votre projet doit impérativement avoir une description";
$lang['project']['no_body']="Votre projet doit impérativement avoir un contenu";
$lang['project']['no_scale']='Votre projet doit impérativement être associé à une échelle';
$lang['project']['no_level']='Votre projet doit impérativement être associé à un niveau';
$lang['project']['no_priority']='Votre projet doit impérativement être associé à une priorité';
$lang['project']['progression_error']='L\'indicateur de réalisation doit prendre une valeur entre 0 et 100.';
$lang['project']['incorrect_user']='Le responsable renseigné \'%s\' est inconnu de l\'application';
$lang['project']['incorrect_userperm']='Le responsable \'%s\' n\'a pas les permissions suffisantes';
$lang['project']['budget_integer']='Budget : un chiffre entier doit être entré';
$lang['project']['begin_date_err']= $lang['project']['begin_date']. ' : ';
$lang['project']['estimated_date_err']=$lang['project']['estimated_date']. ' : ';
$lang['project']['end_date_err']=$lang['project']['end_date']. ' : ';
$lang['project']['inconsistent_date']='Les dates saisies ne semblent pas cohérentes. Veuillez les vérifier.';

/*	rubrique d'aide
 *  	*/
$lang['project']['help_add1']="Pour ajouter un projet, vous devez entrer chacun de ses paramètres dans le formulaire ci-dessus";
$lang['project']['help_add2']="Après avoir validé le formulaire d'ajout, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_add3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour les modifier";

$lang['project']['help_list1']="Pour afficher un projet en détail, cliquez sur le nom de celui-ci";
$lang['project']['help_list2']="Vous pouvez supprimer un projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_list3']="Vous pouvez modifier un projet en cliquant sur l'icône de modification qui lui est associée";
$lang['project']['help_list4']="Pour ajouter un projet, cliquez sur le lien 'ajouter un projet' dans la barre de titre";
$lang['project']['help_list5']="Vous pouvez faire une recherche de projet à tout moment en cliquant sur 'recherche'";

$lang['project']['help_mod1']="Vous pouvez modifier chacun des paramètres dans le formulaire ci-dessus";
$lang['project']['help_mod2']="Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif";
$lang['project']['help_mod3']="Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur 'revoir les paramètres' pour modifier à nouveau les données";

$lang['project']['help_det1']="Pour afficher le projet parent du projet détaillé, cliquez sur le nom de celui-ci";
$lang['project']['help_det2']="Vous pouvez supprimer ce projet en cliquant sur l'icône de suppression qui lui est associée";
$lang['project']['help_det3']="Vous pouvez modifier ce projet en cliquant sur l'icône de modification qui lui est associée";

$lang['project']['help_sup1']="Attention, si ce projet contient des sous projets ils ne seront pas automatiquement effacés";

$lang['task']['status_todo'] = 'à faire';
$lang['task']['status_wip'] = 'en cours';
$lang['task']['status_done'] = 'réalisée';
$lang['task']['progression'] = '%s/%s tâches réalisées (soit %s %%)';
$lang['task']['achieved_at'] = 'marquée comme réalisée le';
$lang['task']['duration'] = 'durée de réalisation';
$lang['task']['months'] = 'mois';
$lang['task']['add'] = 'Ajouter une tâche';
$lang['task']['edit'] = 'Modifier une tâche';
$lang['task']['delete'] = 'Supprimer la tâche';
$lang['task']['deleted_success'] = 'La tâche a été supprimée avec succès';
$lang['task']['edited_success'] = 'La tâche a été modifiée avec succès';
$lang['task']['added_success'] = 'La tâche a été ajoutée avec succès';
$lang['task']['updated_success'] = 'La liste des tâches a été mise à jour';
$lang['task']['label'] = 'Description';
$lang['task']['no_label'] = 'Vous devez impérativement entrer une description pour votre tâche.';
$lang['task']['status'] = 'Statut';
$lang['task']['date_done'] = 'Date de réalisation';
$lang['task']['reminder_freq'] = 'Fréquence de rappel';
$lang['task']['reminder_freq_info'] = 'Seules les tâches avec le statut "<em>A faire</em>" font l\'objet de rappel.';
$lang['task']['reminder_lastdate'] = 'Dernier rappel envoyé le %s';
$lang['task']['reminder_nextdate'] = 'Prochain rappel planifié le %s';
$lang['task']['reminder_freq_noreminder'] = 'Pas de rappel';
$lang['task']['reminder_freq_15days'] = '15 jours';
$lang['task']['reminder_freq_1month'] = '1 mois';
$lang['task']['reminder_freq_3months'] = '3 mois';
$lang['task']['reminder_freq_6months'] = '6 mois';
$lang['task']['reminder_freq_1year'] = '1 an';
$lang['task']['reminder_subject'] = 'encore quelques tâches à accomplir ...';
$lang['task']['reminder_body'] = 'Dans le cadre de la mise en oeuvre de l\'action <a href="%s">%s</a></strong>, n\'oubliez pas que la tâche "<strong>%s</strong>" est à effectuer.';
$lang['task']['reminder_body2'] = '<em>Notez que vous pouvez changer les préférences de rappel en modifant les paramètres de la tâche.</em>';
?>
